==> jc-1.4.0.tar.gz: gnu/java/awt/color/ClutProfileConverter.h <==
// public class gnu.java.awt.color.ClutProfileConverter

// class file dependencies
// @dep_class d46dd1a2b433d63f gnu_java_awt_color_ClutProfileConverter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_ClutProfileConverter_H_
#define _JC_gnu_java_awt_color_ClutProfileConverter_H_

// Forward structure declarations
struct _jc_gnu_java_awt_color_ColorLookUpTable$object;
struct _jc_java_awt_color_ICC__5fProfile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_refs	_jc_gnu_java_awt_color_ClutProfileConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs	_jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$refs	_jc_gnu_java_awt_color_ClutProfileConverter$refs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$nonrefs	_jc_gnu_java_awt_color_ClutProfileConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$object	_jc_gnu_java_awt_color_ClutProfileConverter$object;

typedef const struct _jc_gnu_java_awt_color_ClutProfileConverter$vmethods	_jc_gnu_java_awt_color_ClutProfileConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_ClutProfileConverter$vtable	_jc_gnu_java_awt_color_ClutProfileConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_ClutProfileConverter$vtype	_jc_gnu_java_awt_color_ClutProfileConverter$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_ClutProfileConverter$method$_init$22f5b9f68d921553(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_java_awt_color_ICC__5fProfile$object *);

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$toRGB$8e7372c09e81aa9c;

// Virtual methods structure
struct _jc_gnu_java_awt_color_ClutProfileConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *);
};

// Vtable
struct _jc_gnu_java_awt_color_ClutProfileConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_ClutProfileConverter$vmethods	gnu_java_awt_color_ClutProfileConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_ClutProfileConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_ClutProfileConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_refs {
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*toPCS;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*fromPCS;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_ClutProfileConverter$refs {
    _jc_gnu_java_awt_color_ClutProfileConverter$sub_refs	gnu_java_awt_color_ClutProfileConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs {
	jint	nChannels;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_ClutProfileConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs	gnu_java_awt_color_ClutProfileConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_ClutProfileConverter$object {
	_jc_gnu_java_awt_color_ClutProfileConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_ClutProfileConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_ClutProfileConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_ClutProfileConverter$vtype _jc_gnu_java_awt_color_ClutProfileConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_ClutProfileConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_ClutProfileConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_ClutProfileConverter_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/color/ClutProfileConverter.h <==
// public class gnu.java.awt.color.ClutProfileConverter

// class file dependencies
// @dep_class aa024660ca157a0a gnu_java_awt_color_ClutProfileConverter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_ClutProfileConverter_H_
#define _JC_gnu_java_awt_color_ClutProfileConverter_H_

// Forward structure declarations
struct _jc_gnu_java_awt_color_ColorLookUpTable$object;
struct _jc_java_awt_color_ICC__5fProfile$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_refs	_jc_gnu_java_awt_color_ClutProfileConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs	_jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$refs	_jc_gnu_java_awt_color_ClutProfileConverter$refs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$nonrefs	_jc_gnu_java_awt_color_ClutProfileConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_ClutProfileConverter$object	_jc_gnu_java_awt_color_ClutProfileConverter$object;

typedef const struct _jc_gnu_java_awt_color_ClutProfileConverter$vmethods	_jc_gnu_java_awt_color_ClutProfileConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_ClutProfileConverter$vtable	_jc_gnu_java_awt_color_ClutProfileConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_ClutProfileConverter$vtype	_jc_gnu_java_awt_color_ClutProfileConverter$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_ClutProfileConverter$method$_init$22f5b9f68d921553(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_java_awt_color_ICC__5fProfile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_ClutProfileConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_ClutProfileConverter$method_info$toRGB$8e7372c09e81aa9c;

// Virtual methods structure
struct _jc_gnu_java_awt_color_ClutProfileConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_ClutProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_color_ClutProfileConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_ClutProfileConverter$vmethods	gnu_java_awt_color_ClutProfileConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_ClutProfileConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_ClutProfileConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_refs {
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*toPCS;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*fromPCS;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_ClutProfileConverter$refs {
    _jc_gnu_java_awt_color_ClutProfileConverter$sub_refs	gnu_java_awt_color_ClutProfileConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs {
	jint	nChannels;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_ClutProfileConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_ClutProfileConverter$sub_nonrefs	gnu_java_awt_color_ClutProfileConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_ClutProfileConverter$object {
	_jc_gnu_java_awt_color_ClutProfileConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_ClutProfileConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_ClutProfileConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_ClutProfileConverter$vtype _jc_gnu_java_awt_color_ClutProfileConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_ClutProfileConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_ClutProfileConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_ClutProfileConverter_H_ */
